@@ -10,6 +10,7 @@ import jwt
 import requests.exceptions
 import urllib3
 from requests import Response, Session
+from requests.utils import quote
 from requests.adapters import HTTPAdapter
 from yapconf import YapconfSpec
 
@@ -161,6 +162,7 @@ class RestClient(object):
         self.config_url = self.base_url + "config"
 
         if self.api_version == 1:
+            self.garden_url = self.base_url + "api/v1/gardens/"
             self.system_url = self.base_url + "api/v1/systems/"
             self.instance_url = self.base_url + "api/v1/instances/"
             self.command_url = self.base_url + "api/v1/commands/"
@@ -168,6 +170,8 @@ class RestClient(object):
             self.queue_url = self.base_url + "api/v1/queues/"
             self.logging_url = self.base_url + "api/v1/logging/"
             self.job_url = self.base_url + "api/v1/jobs/"
+            self.job_export_url = self.base_url + "api/v1/export/jobs/"
+            self.job_import_url = self.base_url + "api/v1/import/jobs/"
             self.token_url = self.base_url + "api/v1/tokens/"
             self.user_url = self.base_url + "api/v1/users/"
             self.admin_url = self.base_url + "api/v1/admin/"
@@ -304,6 +308,50 @@ class RestClient(object):
         """
         return self.session.get(self.logging_url, params=kwargs)
 
+    @enable_auth
+    def get_garden(self, garden_name, **kwargs):
+        # type: (str, **Any) -> Response
+        """Performs a GET on the Garden URL
+
+        Args:
+            garden_name: Name of garden to retreive
+            **kwargs: Query parameters to be used in the GET request
+
+        Returns:
+            Requests Response object
+        """
+        # quote will URL encode the Garden name
+        return self.session.get(self.garden_url + quote(garden_name), params=kwargs)
+
+    @enable_auth
+    def post_gardens(self, payload):
+        # type: (str) -> Response
+        """Performs a POST on the Garden URL
+
+        Args:
+            payload: New Garden definition
+
+        Returns:
+            Requests Response object
+        """
+        return self.session.post(
+            self.garden_url, data=payload, headers=self.JSON_HEADERS
+        )
+
+    @enable_auth
+    def delete_garden(self, garden_name):
+        # type: (str) -> Response
+        """Performs a DELETE on a Garden URL
+
+        Args:
+            garden_name: Name of Garden to delete
+
+        Returns:
+            Requests Response object
+        """
+        # quote will URL encode the Garden name
+        return self.session.delete(self.garden_url + quote(garden_name))
+
     @enable_auth
     def get_systems(self, **kwargs):
         # type: (**Any) -> Response
@@ -554,7 +602,7 @@ class RestClient(object):
         Returns:
             Requests Response object
         """
-        return self.session.delete(self.queue_url + queue_name)
+        return self.session.delete(self.queue_url + quote(queue_name))
 
     @enable_auth
     def get_jobs(self, **kwargs):
@@ -595,6 +643,36 @@ class RestClient(object):
         """
         return self.session.post(self.job_url, data=payload, headers=self.JSON_HEADERS)
 
+    @enable_auth
+    def post_export_jobs(self, payload):
+        # type: (str) -> Response
+        """Perform a POST on the Job export URL.
+
+        Args:
+            payload: Serialized list of Jobs
+
+        Returns:
+            Requests Response object
+        """
+        return self.session.post(
+            self.job_export_url, data=payload, headers=self.JSON_HEADERS
+        )
+
+    @enable_auth
+    def post_import_jobs(self, payload):
+        # type: (str) -> Response
+        """Perform a POST on the Job import URL.
+
+        Args:
+            payload: Serialized list of job definitions
+
+        Returns:
+            Requests Response object
+        """
+        return self.session.post(
+            self.job_import_url, data=payload, headers=self.JSON_HEADERS
+        )
+
     @enable_auth
     def patch_job(self, job_id, payload):
         # type: (str, str) -> Response
