@@ -5,7 +5,6 @@ from datetime import datetime
 
 import pytest
 import pytz
-
 from brewtils.models import (
     Choices,
     Command,
@@ -26,7 +25,7 @@ from brewtils.models import (
     RequestFile,
     RequestTemplate,
     Resolvable,
-    Role,
+    LegacyRole,
     Runner,
     System,
 )
@@ -503,11 +502,11 @@ def bg_queue(queue_dict):
 
 
 @pytest.fixture
-def principal_dict(role_dict):
+def principal_dict(legacy_role_dict):
     return {
         "id": "58542eb571afd47ead90d24f",
         "username": "admin",
-        "roles": [role_dict],
+        "roles": [legacy_role_dict],
         "permissions": ["bg-all"],
         "preferences": {"theme": "dark"},
         "metadata": {"foo": "bar"},
@@ -522,7 +521,7 @@ def bg_principal(principal_dict, bg_role):
 
 
 @pytest.fixture
-def role_dict():
+def legacy_role_dict():
     return {
         "id": "58542eb571afd47ead90d26f",
         "name": "bg-admin",
@@ -532,9 +531,9 @@ def role_dict():
 
 
 @pytest.fixture
-def bg_role(role_dict):
-    dict_copy = copy.deepcopy(role_dict)
-    return Role(**dict_copy)
+def bg_role(legacy_role_dict):
+    dict_copy = copy.deepcopy(legacy_role_dict)
+    return LegacyRole(**dict_copy)
 
 
 @pytest.fixture
@@ -557,6 +556,18 @@ def job_dict(ts_epoch, request_template_dict, date_trigger_dict):
     }
 
 
+@pytest.fixture
+def job_id_list_dict(job_dict):
+    """A job ID list represented as a dictionary."""
+    return {"ids": [job_dict["id"]]}
+
+
+@pytest.fixture
+def job_dfn_list_dict(job_dict):
+    """A job definition list represented as a dictionary."""
+    return {"jobs": [job_dict]}
+
+
 @pytest.fixture
 def cron_job_dict(job_dict, cron_trigger_dict):
     """A cron job represented as a dictionary."""
@@ -575,6 +586,22 @@ def interval_job_dict(job_dict, interval_trigger_dict):
     return dict_copy
 
 
+@pytest.fixture
+def job_ids_dict(job_dict):
+    """A list of job IDs represented as a dictionary."""
+    dict_copy = copy.deepcopy(job_dict)
+    return {"ids": [dict_copy["id"]]}
+
+
+@pytest.fixture
+def job_dict_for_import(job_dict):
+    """A job dict but some keys and values are missing."""
+    dict_copy = copy.deepcopy(job_dict)
+    for field in ["id", "next_run_time", "success_count", "error_count"]:
+        dict_copy.pop(field, None)
+    return dict_copy
+
+
 @pytest.fixture
 def bg_job(job_dict, ts_dt, bg_request_template, bg_date_trigger):
     """A job as a model."""
@@ -605,6 +632,19 @@ def bg_interval_job(interval_job_dict, bg_request_template, bg_interval_trigger,
     return Job(**dict_copy)
 
 
+@pytest.fixture
+def bg_job_ids(job_dict):
+    """A list of job IDs"""
+    dict_copy = copy.deepcopy(job_dict)
+    return [str(dict_copy["id"])]
+
+
+@pytest.fixture
+def bg_job_defns_list(job_dict_for_import):
+    """A list of job definitions"""
+    return [Job(**job_dict_for_import)]
+
+
 @pytest.fixture
 def interval_trigger_dict(ts_epoch, ts_2_epoch):
     """An interval trigger as a dictionary."""
